@@ -25,26 +25,24 @@ class DeleteRegistrantProfileRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'DeleteRegistrantProfile')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RegistrantProfileId(self):
+	def get_RegistrantProfileId(self): # Long
 		return self.get_query_params().get('RegistrantProfileId')
 
-	def set_RegistrantProfileId(self,RegistrantProfileId):
-		self.add_query_param('RegistrantProfileId',RegistrantProfileId)
-
-	def get_UserClientIp(self):
+	def set_RegistrantProfileId(self, RegistrantProfileId):  # Long
+		self.add_query_param('RegistrantProfileId', RegistrantProfileId)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_Lang(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
