@@ -25,74 +25,64 @@ class ListServerLockRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'ListServerLock')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_LockProductId(self):
+	def get_LockProductId(self): # String
 		return self.get_query_params().get('LockProductId')
 
-	def set_LockProductId(self,LockProductId):
-		self.add_query_param('LockProductId',LockProductId)
-
-	def get_EndExpireDate(self):
+	def set_LockProductId(self, LockProductId):  # String
+		self.add_query_param('LockProductId', LockProductId)
+	def get_EndExpireDate(self): # Long
 		return self.get_query_params().get('EndExpireDate')
 
-	def set_EndExpireDate(self,EndExpireDate):
-		self.add_query_param('EndExpireDate',EndExpireDate)
-
-	def get_PageNum(self):
+	def set_EndExpireDate(self, EndExpireDate):  # Long
+		self.add_query_param('EndExpireDate', EndExpireDate)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
-
-	def get_BeginStartDate(self):
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_BeginStartDate(self): # Long
 		return self.get_query_params().get('BeginStartDate')
 
-	def set_BeginStartDate(self,BeginStartDate):
-		self.add_query_param('BeginStartDate',BeginStartDate)
-
-	def get_ServerLockStatus(self):
+	def set_BeginStartDate(self, BeginStartDate):  # Long
+		self.add_query_param('BeginStartDate', BeginStartDate)
+	def get_ServerLockStatus(self): # Integer
 		return self.get_query_params().get('ServerLockStatus')
 
-	def set_ServerLockStatus(self,ServerLockStatus):
-		self.add_query_param('ServerLockStatus',ServerLockStatus)
-
-	def get_StartExpireDate(self):
+	def set_ServerLockStatus(self, ServerLockStatus):  # Integer
+		self.add_query_param('ServerLockStatus', ServerLockStatus)
+	def get_StartExpireDate(self): # Long
 		return self.get_query_params().get('StartExpireDate')
 
-	def set_StartExpireDate(self,StartExpireDate):
-		self.add_query_param('StartExpireDate',StartExpireDate)
-
-	def get_PageSize(self):
+	def set_StartExpireDate(self, StartExpireDate):  # Long
+		self.add_query_param('StartExpireDate', StartExpireDate)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Lang(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_DomainName(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_EndStartDate(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_EndStartDate(self): # Long
 		return self.get_query_params().get('EndStartDate')
 
-	def set_EndStartDate(self,EndStartDate):
-		self.add_query_param('EndStartDate',EndStartDate)
-
-	def get_UserClientIp(self):
+	def set_EndStartDate(self, EndStartDate):  # Long
+		self.add_query_param('EndStartDate', EndStartDate)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
\ No newline at end of file
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
