@@ -23,28 +23,26 @@ from aliyunsdkdomain.endpoint import endpoint_data
 class LookupTmchNoticeRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'LookupTmchNotice','domain')
+		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'LookupTmchNotice')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ClaimKey(self):
+	def get_ClaimKey(self): # String
 		return self.get_query_params().get('ClaimKey')
 
-	def set_ClaimKey(self,ClaimKey):
-		self.add_query_param('ClaimKey',ClaimKey)
-
-	def get_UserClientIp(self):
+	def set_ClaimKey(self, ClaimKey):  # String
+		self.add_query_param('ClaimKey', ClaimKey)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_Lang(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
