@@ -25,26 +25,24 @@ class QueryFailReasonForRegistrantProfileRealNameVerificationRequest(RpcRequest)
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'QueryFailReasonForRegistrantProfileRealNameVerification')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_RegistrantProfileID(self):
+	def get_RegistrantProfileID(self): # Long
 		return self.get_query_params().get('RegistrantProfileID')
 
-	def set_RegistrantProfileID(self,RegistrantProfileID):
-		self.add_query_param('RegistrantProfileID',RegistrantProfileID)
-
-	def get_UserClientIp(self):
+	def set_RegistrantProfileID(self, RegistrantProfileID):  # Long
+		self.add_query_param('RegistrantProfileID', RegistrantProfileID)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_Lang(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
