@@ -25,20 +25,19 @@ class QueryOperationAuditInfoDetailRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'QueryOperationAuditInfoDetail')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_AuditRecordId(self):
+	def get_AuditRecordId(self): # Long
 		return self.get_query_params().get('AuditRecordId')
 
-	def set_AuditRecordId(self,AuditRecordId):
-		self.add_query_param('AuditRecordId',AuditRecordId)
-
-	def get_Lang(self):
+	def set_AuditRecordId(self, AuditRecordId):  # Long
+		self.add_query_param('AuditRecordId', AuditRecordId)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
