@@ -25,56 +25,49 @@ class QueryTaskDetailHistoryRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'QueryTaskDetailHistory')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DomainName(self):
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_TaskStatus(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_TaskStatus(self): # Integer
 		return self.get_query_params().get('TaskStatus')
 
-	def set_TaskStatus(self,TaskStatus):
-		self.add_query_param('TaskStatus',TaskStatus)
-
-	def get_UserClientIp(self):
+	def set_TaskStatus(self, TaskStatus):  # Integer
+		self.add_query_param('TaskStatus', TaskStatus)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_TaskNo(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_TaskNo(self): # String
 		return self.get_query_params().get('TaskNo')
 
-	def set_TaskNo(self,TaskNo):
-		self.add_query_param('TaskNo',TaskNo)
-
-	def get_PageSize(self):
+	def set_TaskNo(self, TaskNo):  # String
+		self.add_query_param('TaskNo', TaskNo)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_TaskDetailNoCursor(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_TaskDetailNoCursor(self): # String
 		return self.get_query_params().get('TaskDetailNoCursor')
 
-	def set_TaskDetailNoCursor(self,TaskDetailNoCursor):
-		self.add_query_param('TaskDetailNoCursor',TaskDetailNoCursor)
-
-	def get_Lang(self):
+	def set_TaskDetailNoCursor(self, TaskDetailNoCursor):  # String
+		self.add_query_param('TaskDetailNoCursor', TaskDetailNoCursor)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_DomainNameCursor(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_DomainNameCursor(self): # String
 		return self.get_query_params().get('DomainNameCursor')
 
-	def set_DomainNameCursor(self,DomainNameCursor):
-		self.add_query_param('DomainNameCursor',DomainNameCursor)
\ No newline at end of file
+	def set_DomainNameCursor(self, DomainNameCursor):  # String
+		self.add_query_param('DomainNameCursor', DomainNameCursor)
