@@ -25,56 +25,49 @@ class QueryTransferInListRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'QueryTransferInList')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SubmissionStartDate(self):
+	def get_SubmissionStartDate(self): # Long
 		return self.get_query_params().get('SubmissionStartDate')
 
-	def set_SubmissionStartDate(self,SubmissionStartDate):
-		self.add_query_param('SubmissionStartDate',SubmissionStartDate)
-
-	def get_SubmissionEndDate(self):
+	def set_SubmissionStartDate(self, SubmissionStartDate):  # Long
+		self.add_query_param('SubmissionStartDate', SubmissionStartDate)
+	def get_SubmissionEndDate(self): # Long
 		return self.get_query_params().get('SubmissionEndDate')
 
-	def set_SubmissionEndDate(self,SubmissionEndDate):
-		self.add_query_param('SubmissionEndDate',SubmissionEndDate)
-
-	def get_DomainName(self):
+	def set_SubmissionEndDate(self, SubmissionEndDate):  # Long
+		self.add_query_param('SubmissionEndDate', SubmissionEndDate)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_PageNum(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_PageNum(self): # Integer
 		return self.get_query_params().get('PageNum')
 
-	def set_PageNum(self,PageNum):
-		self.add_query_param('PageNum',PageNum)
-
-	def get_UserClientIp(self):
+	def set_PageNum(self, PageNum):  # Integer
+		self.add_query_param('PageNum', PageNum)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_SimpleTransferInStatus(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_SimpleTransferInStatus(self): # String
 		return self.get_query_params().get('SimpleTransferInStatus')
 
-	def set_SimpleTransferInStatus(self,SimpleTransferInStatus):
-		self.add_query_param('SimpleTransferInStatus',SimpleTransferInStatus)
-
-	def get_PageSize(self):
+	def set_SimpleTransferInStatus(self, SimpleTransferInStatus):  # String
+		self.add_query_param('SimpleTransferInStatus', SimpleTransferInStatus)
+	def get_PageSize(self): # Integer
 		return self.get_query_params().get('PageSize')
 
-	def set_PageSize(self,PageSize):
-		self.add_query_param('PageSize',PageSize)
-
-	def get_Lang(self):
+	def set_PageSize(self, PageSize):  # Integer
+		self.add_query_param('PageSize', PageSize)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
