@@ -23,34 +23,31 @@ from aliyunsdkdomain.endpoint import endpoint_data
 class SaveDomainGroupRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveDomainGroup','domain')
+		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveDomainGroup')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DomainGroupId(self):
+	def get_DomainGroupId(self): # Long
 		return self.get_query_params().get('DomainGroupId')
 
-	def set_DomainGroupId(self,DomainGroupId):
-		self.add_query_param('DomainGroupId',DomainGroupId)
-
-	def get_UserClientIp(self):
+	def set_DomainGroupId(self, DomainGroupId):  # Long
+		self.add_query_param('DomainGroupId', DomainGroupId)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_DomainGroupName(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_DomainGroupName(self): # String
 		return self.get_query_params().get('DomainGroupName')
 
-	def set_DomainGroupName(self,DomainGroupName):
-		self.add_query_param('DomainGroupName',DomainGroupName)
-
-	def get_Lang(self):
+	def set_DomainGroupName(self, DomainGroupName):  # String
+		self.add_query_param('DomainGroupName', DomainGroupName)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
