@@ -25,56 +25,49 @@ class SaveSingleTaskForCreatingOrderRedeemRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveSingleTaskForCreatingOrderRedeem')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_DomainName(self):
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_CouponNo(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_CouponNo(self): # String
 		return self.get_query_params().get('CouponNo')
 
-	def set_CouponNo(self,CouponNo):
-		self.add_query_param('CouponNo',CouponNo)
-
-	def get_UseCoupon(self):
+	def set_CouponNo(self, CouponNo):  # String
+		self.add_query_param('CouponNo', CouponNo)
+	def get_UseCoupon(self): # Boolean
 		return self.get_query_params().get('UseCoupon')
 
-	def set_UseCoupon(self,UseCoupon):
-		self.add_query_param('UseCoupon',UseCoupon)
-
-	def get_PromotionNo(self):
+	def set_UseCoupon(self, UseCoupon):  # Boolean
+		self.add_query_param('UseCoupon', UseCoupon)
+	def get_PromotionNo(self): # String
 		return self.get_query_params().get('PromotionNo')
 
-	def set_PromotionNo(self,PromotionNo):
-		self.add_query_param('PromotionNo',PromotionNo)
-
-	def get_CurrentExpirationDate(self):
+	def set_PromotionNo(self, PromotionNo):  # String
+		self.add_query_param('PromotionNo', PromotionNo)
+	def get_CurrentExpirationDate(self): # Long
 		return self.get_query_params().get('CurrentExpirationDate')
 
-	def set_CurrentExpirationDate(self,CurrentExpirationDate):
-		self.add_query_param('CurrentExpirationDate',CurrentExpirationDate)
-
-	def get_UserClientIp(self):
+	def set_CurrentExpirationDate(self, CurrentExpirationDate):  # Long
+		self.add_query_param('CurrentExpirationDate', CurrentExpirationDate)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_Lang(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_UsePromotion(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_UsePromotion(self): # Boolean
 		return self.get_query_params().get('UsePromotion')
 
-	def set_UsePromotion(self,UsePromotion):
-		self.add_query_param('UsePromotion',UsePromotion)
\ No newline at end of file
+	def set_UsePromotion(self, UsePromotion):  # Boolean
+		self.add_query_param('UsePromotion', UsePromotion)
