@@ -25,80 +25,69 @@ class SaveSingleTaskForSaveArtExtensionRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveSingleTaskForSaveArtExtension')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_Subject(self):
+	def get_Subject(self): # String
 		return self.get_query_params().get('Subject')
 
-	def set_Subject(self,Subject):
-		self.add_query_param('Subject',Subject)
-
-	def get_Title(self):
+	def set_Subject(self, Subject):  # String
+		self.add_query_param('Subject', Subject)
+	def get_Title(self): # String
 		return self.get_query_params().get('Title')
 
-	def set_Title(self,Title):
-		self.add_query_param('Title',Title)
-
-	def get_DateOrPeriod(self):
+	def set_Title(self, Title):  # String
+		self.add_query_param('Title', Title)
+	def get_DateOrPeriod(self): # String
 		return self.get_query_params().get('DateOrPeriod')
 
-	def set_DateOrPeriod(self,DateOrPeriod):
-		self.add_query_param('DateOrPeriod',DateOrPeriod)
-
-	def get_Reference(self):
+	def set_DateOrPeriod(self, DateOrPeriod):  # String
+		self.add_query_param('DateOrPeriod', DateOrPeriod)
+	def get_Reference(self): # String
 		return self.get_query_params().get('Reference')
 
-	def set_Reference(self,Reference):
-		self.add_query_param('Reference',Reference)
-
-	def get_Features(self):
+	def set_Reference(self, Reference):  # String
+		self.add_query_param('Reference', Reference)
+	def get_Features(self): # String
 		return self.get_query_params().get('Features')
 
-	def set_Features(self,Features):
-		self.add_query_param('Features',Features)
-
-	def get_InscriptionsAndMarkings(self):
+	def set_Features(self, Features):  # String
+		self.add_query_param('Features', Features)
+	def get_InscriptionsAndMarkings(self): # String
 		return self.get_query_params().get('InscriptionsAndMarkings')
 
-	def set_InscriptionsAndMarkings(self,InscriptionsAndMarkings):
-		self.add_query_param('InscriptionsAndMarkings',InscriptionsAndMarkings)
-
-	def get_ObjectType(self):
+	def set_InscriptionsAndMarkings(self, InscriptionsAndMarkings):  # String
+		self.add_query_param('InscriptionsAndMarkings', InscriptionsAndMarkings)
+	def get_ObjectType(self): # String
 		return self.get_query_params().get('ObjectType')
 
-	def set_ObjectType(self,ObjectType):
-		self.add_query_param('ObjectType',ObjectType)
-
-	def get_Lang(self):
+	def set_ObjectType(self, ObjectType):  # String
+		self.add_query_param('ObjectType', ObjectType)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_DomainName(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_Maker(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_Maker(self): # String
 		return self.get_query_params().get('Maker')
 
-	def set_Maker(self,Maker):
-		self.add_query_param('Maker',Maker)
-
-	def get_MaterialsAndTechniques(self):
+	def set_Maker(self, Maker):  # String
+		self.add_query_param('Maker', Maker)
+	def get_MaterialsAndTechniques(self): # String
 		return self.get_query_params().get('MaterialsAndTechniques')
 
-	def set_MaterialsAndTechniques(self,MaterialsAndTechniques):
-		self.add_query_param('MaterialsAndTechniques',MaterialsAndTechniques)
-
-	def get_Dimensions(self):
+	def set_MaterialsAndTechniques(self, MaterialsAndTechniques):  # String
+		self.add_query_param('MaterialsAndTechniques', MaterialsAndTechniques)
+	def get_Dimensions(self): # String
 		return self.get_query_params().get('Dimensions')
 
-	def set_Dimensions(self,Dimensions):
-		self.add_query_param('Dimensions',Dimensions)
\ No newline at end of file
+	def set_Dimensions(self, Dimensions):  # String
+		self.add_query_param('Dimensions', Dimensions)
