@@ -25,50 +25,44 @@ class SaveSingleTaskForUpdatingContactInfoRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SaveSingleTaskForUpdatingContactInfo')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_ContactType(self):
+	def get_ContactType(self): # String
 		return self.get_query_params().get('ContactType')
 
-	def set_ContactType(self,ContactType):
-		self.add_query_param('ContactType',ContactType)
-
-	def get_DomainName(self):
+	def set_ContactType(self, ContactType):  # String
+		self.add_query_param('ContactType', ContactType)
+	def get_DomainName(self): # String
 		return self.get_query_params().get('DomainName')
 
-	def set_DomainName(self,DomainName):
-		self.add_query_param('DomainName',DomainName)
-
-	def get_RegistrantProfileId(self):
+	def set_DomainName(self, DomainName):  # String
+		self.add_query_param('DomainName', DomainName)
+	def get_RegistrantProfileId(self): # Long
 		return self.get_query_params().get('RegistrantProfileId')
 
-	def set_RegistrantProfileId(self,RegistrantProfileId):
-		self.add_query_param('RegistrantProfileId',RegistrantProfileId)
-
-	def get_AddTransferLock(self):
+	def set_RegistrantProfileId(self, RegistrantProfileId):  # Long
+		self.add_query_param('RegistrantProfileId', RegistrantProfileId)
+	def get_AddTransferLock(self): # Boolean
 		return self.get_query_params().get('AddTransferLock')
 
-	def set_AddTransferLock(self,AddTransferLock):
-		self.add_query_param('AddTransferLock',AddTransferLock)
-
-	def get_InstanceId(self):
+	def set_AddTransferLock(self, AddTransferLock):  # Boolean
+		self.add_query_param('AddTransferLock', AddTransferLock)
+	def get_InstanceId(self): # String
 		return self.get_query_params().get('InstanceId')
 
-	def set_InstanceId(self,InstanceId):
-		self.add_query_param('InstanceId',InstanceId)
-
-	def get_UserClientIp(self):
+	def set_InstanceId(self, InstanceId):  # String
+		self.add_query_param('InstanceId', InstanceId)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_Lang(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
\ No newline at end of file
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
