@@ -25,32 +25,29 @@ class SubmitEmailVerificationRequest(RpcRequest):
 	def __init__(self):
 		RpcRequest.__init__(self, 'Domain', '2018-01-29', 'SubmitEmailVerification')
 		self.set_method('POST')
+
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
 		if hasattr(self, "endpoint_regional"):
 			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())
 
-
-	def get_SendIfExist(self):
+	def get_SendIfExist(self): # Boolean
 		return self.get_query_params().get('SendIfExist')
 
-	def set_SendIfExist(self,SendIfExist):
-		self.add_query_param('SendIfExist',SendIfExist)
-
-	def get_UserClientIp(self):
+	def set_SendIfExist(self, SendIfExist):  # Boolean
+		self.add_query_param('SendIfExist', SendIfExist)
+	def get_UserClientIp(self): # String
 		return self.get_query_params().get('UserClientIp')
 
-	def set_UserClientIp(self,UserClientIp):
-		self.add_query_param('UserClientIp',UserClientIp)
-
-	def get_Lang(self):
+	def set_UserClientIp(self, UserClientIp):  # String
+		self.add_query_param('UserClientIp', UserClientIp)
+	def get_Lang(self): # String
 		return self.get_query_params().get('Lang')
 
-	def set_Lang(self,Lang):
-		self.add_query_param('Lang',Lang)
-
-	def get_Email(self):
+	def set_Lang(self, Lang):  # String
+		self.add_query_param('Lang', Lang)
+	def get_Email(self): # String
 		return self.get_query_params().get('Email')
 
-	def set_Email(self,Email):
-		self.add_query_param('Email',Email)
\ No newline at end of file
+	def set_Email(self, Email):  # String
+		self.add_query_param('Email', Email)
